@@ -46,7 +46,7 @@ raw values read out
 """
 
 
-__version__ = '1.3.1'
+__version__ = '1.3.2'
 
 import serial
 import time
@@ -146,6 +146,11 @@ def get_log_settings():
         if setting in choices_for_set and setting != "run":
             resp = get_mvm_param(ser, setting)
             if(resp is not False):
+                # This is dirty, but effective
+                try:
+                    resp = int(resp)
+                except Exception:
+                    resp = float(resp)
                 settings_resp[setting] = resp
 
     return settings_resp
